# Tools
## Analytics
- [Get Codec](/tools/analytics/get_codec): Get overview of all used characters (codec) in a data set
- [Get Text Count](/tools/analytics/get_text_count): Get overview of text contained in data set
## Management
:::info
TODO
:::
## Transformation
- [Change Index](/tools/analytics/get_codec): Change index of elements
- [Extraction](/tools/analytics/get_codec): Extract elements as images and optionally their text content
- [Line2Page](/tools/analytics/get_codec): Merges line images and line texts into combined images and PAGE XML files
- [Regularization](/tools/analytics/get_codec): Regularize the text content of PAGE XML files using custom rulesets. 